@@ -4,7 +4,7 @@
 // Invenio RDM Records is free software; you can redistribute it and/or modify it
 // under the terms of the MIT License; see LICENSE file for more details.
 export {
-  RequestLinkExtractor,
+  RequestLinksExtractor,
   InvenioRequestEventsApi,
   InvenioRequestsAPI,
 } from "./api";
